=== added directory 'yelp'
=== added file 'yelp/test_yelp.py'
--- yelp/test_yelp.py	1970-01-01 00:00:00 +0000
+++ yelp/test_yelp.py	2011-01-31 18:12:58 +0000
@@ -0,0 +1,92 @@
+# Copyright (C) 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Yelp Test
+
+This is a basic test to verify that yelp is working correctly.
+
+It checks the following:
+    - that searching for Shuttleworth returns a reference to Mark.
+    - that following all links on the home page doesn't crash.
+
+Disabled test:
+    - that following a link while loading a search result causes a crash
+
+To run it with:
+$ mago-ng <path_to_this_file>
+"""
+
+from mago import TestCase
+import ldtp
+import ooldtp
+import unittest
+
+
+class YelpTests(TestCase):
+    """Launcher for the application yelp.
+    """
+    launcher = 'yelp'
+    window_name = 'frmDesktopUserGuide'
+
+    def test_search(self):
+        """Test search
+
+        Test that searching for Shuttleworth returns a reference to Mark.
+        """
+        # searching isn't implemented yet
+        # FIXME: search_activated
+        context = ooldtp.context(self.window_name)
+        context.settextvalue('txt0', 'Shuttleworth')
+        context.enterstring('txt0', '<enter>')
+        ldtp.wait(2)
+        self.assertTrue('mark shuttleworth' in
+                        context.gettextvalue('txt1'))
+
+    def ttest_follow_link_while_loading_crash(self):
+        """Create a crash
+
+        Test that following a link while loading a search result causes a
+        crash.
+        """
+        context = ooldtp.context(self.window_name)
+        context.settextvalue('txtSearch', 'network')
+        context.enterstring('txtSearch', '<enter>')
+        ldtp.waittillguiexist('frmnetwork')
+        ldtp.mouseleftclick('frmnetwork', 'Office')
+        ldtp.waittillguiexist('frmLoading*')
+        ldtp.wait(2)
+        ldtp.mouseleftclick('frmLoading*', 'Office')
+        self.assertTrue(ldtp.guiexist('frmLoading*'))
+
+    def test_follow_all_links_from_home(self):
+        """Click all links on the home page
+
+        Test that following all links on the home page doesn't crash.
+        Apparently some of the ukn links cause yelp to close so start with 12.
+        """
+        links = [item for item in ldtp.getobjectlist(self.window_name)
+                 if 'ukn' in item]
+        for link in links:
+            if int(link.replace('ukn', '')) > 11:
+                ldtp.waittillguiexist(self.window_name)
+                ldtp.mouseleftclick(self.window_name, link)
+                ldtp.wait(2)
+                wname = self.application.get_windowname(discover=True)
+                ldtp.waittillguiexist(wname)
+                ldtp.mouseleftclick(wname, 'btnBack')
+
+if __name__ == "__main__":
+    unittest.main()

